@@ -10,10 +10,22 @@ class AtlantisClient:
     :param str client_secret: Secret do cliente cadastrado no Atlantis
     """
 
-    def __init__(self, client_id, client_secret, atlantis_url='https://accounts.spacetimeanalytics.com'):
+    def __init__(self, client_id=None, client_secret=None, atlantis_url='https://accounts.spacetimeanalytics.com'):
         self.atlantis_url = atlantis_url
-        self.client_id = client_id
-        self.client_secret = client_secret
+        self._client_id = client_id
+        self._client_secret = client_secret
+
+    @property
+    def client_id(self):
+        if self._client_id is None:
+            raise InvalidInitParameters('invalid initialization of the required parameters.')
+        return self._client_id
+
+    @property
+    def client_secret(self):
+        if self._client_secret is None:
+            raise InvalidInitParameters('invalid initialization of the required parameters.')
+        return self._client_secret
 
     def issue_token(self, code):
         """Realiza a troca do code pelo token
@@ -125,5 +137,23 @@ class AtlantisClient:
         return response.json()
 
 
+class AtlantisClientFlask(AtlantisClient):
+
+    def __init__(self, app=None):
+        self.app = app
+        if app is not None:
+            self.init_app(app)
+        super().__init__()
+
+    def init_app(self, app):
+        self.atlantis_url = app.config['ATLANTIS_URL']
+        self._client_id = app.config['ATLANTIS_CLIENT_ID']
+        self._client_secret = app.config['ATLANTIS_CLIENT_SECRET']
+
+
 class InvalidTokenError(RuntimeError):
     pass
+
+
+class InvalidInitParameters(RuntimeError):
+    pass
